@@ -1,4 +1,4 @@
-# Copyright 2010-2021 Gentoo Authors
+# Copyright 2010-2025 Gentoo Authors
 # Distributed under the terms of the GNU General Public License v2
 
 __all__ = ("UseManager",)
@@ -6,24 +6,20 @@ __all__ = ("UseManager",)
 from _emerge.Package import Package
 from portage import os
 from portage.dep import (
-    Atom,
     dep_getrepo,
     dep_getslot,
     ExtendedAtomDict,
     remove_slot,
     _get_useflag_re,
-    _repo_separator,
 )
 from portage.eapi import (
-    eapi_has_use_aliases,
+    eapi_supports_use_stable,
     eapi_supports_stable_use_forcing_and_masking,
 )
-from portage.exception import InvalidAtom
 from portage.localization import _
 from portage.repository.config import allow_profile_repo_deps
 from portage.util import (
     grabfile,
-    grabdict,
     grabdict_package,
     read_corresponding_eapi_file,
     stack_lists,
@@ -43,23 +39,25 @@ class UseManager:
         # 	repositories
         # --------------------------------
         # 	use.mask			_repo_usemask_dict
+        # 	use.stable			_repo_use_stable_dict
         # 	use.stable.mask			_repo_usestablemask_dict
         # 	use.force			_repo_useforce_dict
         # 	use.stable.force		_repo_usestableforce_dict
-        # 	use.aliases			_repo_usealiases_dict
         # 	package.use.mask		_repo_pusemask_dict
+        # 	package.use.stable		_repo_puse_stable_dict
         # 	package.use.stable.mask		_repo_pusestablemask_dict
         # 	package.use.force		_repo_puseforce_dict
         # 	package.use.stable.force	_repo_pusestableforce_dict
-        # 	package.use.aliases		_repo_pusealiases_dict
         # --------------------------------
         # 	profiles
         # --------------------------------
         # 	use.mask			_usemask_list
+        # 	use.stable			_use_stable_list
         # 	use.stable.mask			_usestablemask_list
         # 	use.force			_useforce_list
         # 	use.stable.force		_usestableforce_list
         # 	package.use.mask		_pusemask_list
+        # 	package.use.stable		_puse_stable_list
         # 	package.use.stable.mask		_pusestablemask_list
         # 	package.use			_pkgprofileuse
         # 	package.use.force		_puseforce_list
@@ -85,6 +83,11 @@ class UseManager:
         self._repo_usemask_dict = self._parse_repository_files_to_dict_of_tuples(
             "use.mask", repositories
         )
+        self._repo_use_stable_dict = self._parse_repository_files_to_dict_of_tuples(
+            "use.stable",
+            repositories,
+            eapi_filter=eapi_supports_use_stable,
+        )
         self._repo_usestablemask_dict = self._parse_repository_files_to_dict_of_tuples(
             "use.stable.mask",
             repositories,
@@ -101,6 +104,11 @@ class UseManager:
         self._repo_pusemask_dict = self._parse_repository_files_to_dict_of_dicts(
             "package.use.mask", repositories
         )
+        self._repo_puse_stable_dict = self._parse_repository_files_to_dict_of_dicts(
+            "package.use.stable",
+            repositories,
+            eapi_filter=eapi_supports_use_stable,
+        )
         self._repo_pusestablemask_dict = self._parse_repository_files_to_dict_of_dicts(
             "package.use.stable.mask",
             repositories,
@@ -121,6 +129,11 @@ class UseManager:
         self._usemask_list = self._parse_profile_files_to_tuple_of_tuples(
             "use.mask", profiles
         )
+        self._use_stable_list = self._parse_profile_files_to_tuple_of_tuples(
+            "use.stable",
+            profiles,
+            eapi_filter=eapi_supports_use_stable,
+        )
         self._usestablemask_list = self._parse_profile_files_to_tuple_of_tuples(
             "use.stable.mask",
             profiles,
@@ -137,6 +150,12 @@ class UseManager:
         self._pusemask_list = self._parse_profile_files_to_tuple_of_dicts(
             "package.use.mask", profiles
         )
+        self._puse_stable_list = self._parse_profile_files_to_tuple_of_dicts(
+            "package.use.stable",
+            profiles,
+            eapi_filter=eapi_supports_use_stable,
+            juststrings=True,
+        )
         self._pusestablemask_list = self._parse_profile_files_to_tuple_of_dicts(
             "package.use.stable.mask",
             profiles,
@@ -158,11 +177,6 @@ class UseManager:
             "package.use", abs_user_config, user_config
         )
 
-        self._repo_usealiases_dict = self._parse_repository_usealiases(repositories)
-        self._repo_pusealiases_dict = self._parse_repository_packageusealiases(
-            repositories
-        )
-
         self.repositories = repositories
 
     def _parse_file_to_tuple(
@@ -409,111 +423,6 @@ class UseManager:
             for profile in locations
         )
 
-    def _parse_repository_usealiases(self, repositories):
-        ret = {}
-        for repo in repositories.repos_with_profiles():
-            file_name = os.path.join(repo.location, "profiles", "use.aliases")
-            eapi = read_corresponding_eapi_file(file_name, default=repo.eapi)
-            useflag_re = _get_useflag_re(eapi)
-            raw_file_dict = grabdict(file_name, recursive=True)
-            file_dict = {}
-            for real_flag, aliases in raw_file_dict.items():
-                if useflag_re.match(real_flag) is None:
-                    writemsg(
-                        _("--- Invalid real USE flag in '%s': '%s'\n")
-                        % (file_name, real_flag),
-                        noiselevel=-1,
-                    )
-                else:
-                    for alias in aliases:
-                        if useflag_re.match(alias) is None:
-                            writemsg(
-                                _(
-                                    "--- Invalid USE flag alias for '%s' real USE flag in '%s': '%s'\n"
-                                )
-                                % (real_flag, file_name, alias),
-                                noiselevel=-1,
-                            )
-                        else:
-                            if any(
-                                alias in v
-                                for k, v in file_dict.items()
-                                if k != real_flag
-                            ):
-                                writemsg(
-                                    _("--- Duplicated USE flag alias in '%s': '%s'\n")
-                                    % (file_name, alias),
-                                    noiselevel=-1,
-                                )
-                            else:
-                                file_dict.setdefault(real_flag, []).append(alias)
-            ret[repo.name] = file_dict
-        return ret
-
-    def _parse_repository_packageusealiases(self, repositories):
-        ret = {}
-        for repo in repositories.repos_with_profiles():
-            file_name = os.path.join(repo.location, "profiles", "package.use.aliases")
-            eapi = read_corresponding_eapi_file(file_name, default=repo.eapi)
-            useflag_re = _get_useflag_re(eapi)
-            lines = grabfile(file_name, recursive=True)
-            file_dict = {}
-            for line in lines:
-                elements = line.split()
-                atom = elements[0]
-                try:
-                    atom = Atom(atom, eapi=eapi)
-                except InvalidAtom:
-                    writemsg(_("--- Invalid atom in '%s': '%s'\n") % (file_name, atom))
-                    continue
-                if len(elements) == 1:
-                    writemsg(
-                        _("--- Missing real USE flag for '%s' in '%s'\n")
-                        % (atom, file_name),
-                        noiselevel=-1,
-                    )
-                    continue
-                real_flag = elements[1]
-                if useflag_re.match(real_flag) is None:
-                    writemsg(
-                        _("--- Invalid real USE flag for '%s' in '%s': '%s'\n")
-                        % (atom, file_name, real_flag),
-                        noiselevel=-1,
-                    )
-                else:
-                    for alias in elements[2:]:
-                        if useflag_re.match(alias) is None:
-                            writemsg(
-                                _(
-                                    "--- Invalid USE flag alias for '%s' real USE flag for '%s' in '%s': '%s'\n"
-                                )
-                                % (real_flag, atom, file_name, alias),
-                                noiselevel=-1,
-                            )
-                        else:
-                            # Duplicated USE flag aliases in entries for different atoms
-                            # matching the same package version are detected in getUseAliases().
-                            if any(
-                                alias in v
-                                for k, v in file_dict.get(atom.cp, {})
-                                .get(atom, {})
-                                .items()
-                                if k != real_flag
-                            ):
-                                writemsg(
-                                    _(
-                                        "--- Duplicated USE flag alias for '%s' in '%s': '%s'\n"
-                                    )
-                                    % (atom, file_name, alias),
-                                    noiselevel=-1,
-                                )
-                            else:
-                                file_dict.setdefault(atom.cp, {}).setdefault(
-                                    atom, {}
-                                ).setdefault(real_flag, []).append(alias)
-            ret[repo.name] = file_dict
-        return ret
-
     def _isStable(self, pkg):
         if self._user_config:
             try:
@@ -650,65 +559,6 @@ class UseManager:
 
         return frozenset(stack_lists(useforce, incremental=True))
 
-    def getUseAliases(self, pkg):
-        if hasattr(pkg, "eapi") and not eapi_has_use_aliases(pkg.eapi):
-            return {}
-
-        cp = getattr(pkg, "cp", None)
-        if cp is None:
-            slot = dep_getslot(pkg)
-            repo = dep_getrepo(pkg)
-            pkg = _pkg_str(remove_slot(pkg), slot=slot, repo=repo)
-            cp = pkg.cp
-
-        usealiases = {}
-
-        if hasattr(pkg, "repo") and pkg.repo != Package.UNKNOWN_REPO:
-            repos = []
-            try:
-                repos.extend(repo.name for repo in self.repositories[pkg.repo].masters)
-            except KeyError:
-                pass
-            repos.append(pkg.repo)
-            for repo in repos:
-                usealiases_dict = self._repo_usealiases_dict.get(repo, {})
-                for real_flag, aliases in usealiases_dict.items():
-                    for alias in aliases:
-                        if any(
-                            alias in v for k, v in usealiases.items() if k != real_flag
-                        ):
-                            writemsg(
-                                _("--- Duplicated USE flag alias for '%s%s%s': '%s'\n")
-                                % (pkg.cpv, _repo_separator, pkg.repo, alias),
-                                noiselevel=-1,
-                            )
-                        else:
-                            usealiases.setdefault(real_flag, []).append(alias)
-                cp_usealiases_dict = self._repo_pusealiases_dict.get(repo, {}).get(cp)
-                if cp_usealiases_dict:
-                    usealiases_dict_list = ordered_by_atom_specificity(
-                        cp_usealiases_dict, pkg
-                    )
-                    for usealiases_dict in usealiases_dict_list:
-                        for real_flag, aliases in usealiases_dict.items():
-                            for alias in aliases:
-                                if any(
-                                    alias in v
-                                    for k, v in usealiases.items()
-                                    if k != real_flag
-                                ):
-                                    writemsg(
-                                        _(
-                                            "--- Duplicated USE flag alias for '%s%s%s': '%s'\n"
-                                        )
-                                        % (pkg.cpv, _repo_separator, pkg.repo, alias),
-                                        noiselevel=-1,
-                                    )
-                                else:
-                                    usealiases.setdefault(real_flag, []).append(alias)
-
-        return usealiases
-
     def getPUSE(self, pkg):
         cp = getattr(pkg, "cp", None)
         if cp is None:
